=== added directory 'image-builder'
=== added file 'image-builder/README.imagebuilder'
--- image-builder/README.imagebuilder	1970-01-01 00:00:00 +0000
+++ image-builder/README.imagebuilder	2013-12-12 05:20:33 +0000
@@ -0,0 +1,32 @@
+Local Development
+-----------------
+
+Development environments can be set of using the setup.py files in the
+projects you wish to work on. The easiest approach is to use python-virtualenv::
+
+  virtualenv /tmp/venv
+  . /tmp/venv/bin/activate
+  ./setup.py develop
+
+Unit-testing can be done with::
+
+  python -m unittest imagebuilder.tests.test_api_v1
+
+Running under the python wsgi server can be done with::
+
+  ./imagebuilder/wsgi.py
+
+Running under gunicorn can be done with::
+
+  # need gunicorn:
+  pip install gunicorn
+
+  # TIP: by setting max-requests=1 you can make changes to the source code
+  # and they'll be picked up in the next http request you make!!
+  gunicorn --max-requests 1 imagebuilder.wsgi:app
+
+Juju Testing
+------------
+
+Each service should include a juju-deployer config under the juju-deployer
+directory.

=== added directory 'image-builder/imagebuilder'
=== added file 'image-builder/imagebuilder/__init__.py'
--- image-builder/imagebuilder/__init__.py	1970-01-01 00:00:00 +0000
+++ image-builder/imagebuilder/__init__.py	2013-12-12 05:20:33 +0000
@@ -0,0 +1,17 @@
+# Ubuntu CI Services
+# Copyright 2013 Canonical Ltd.
+
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License version 3, as
+# published by the Free Software Foundation.
+
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+# PURPOSE.  See the GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+# TODO make this probe from changelog or bzr
+__version__ = '0.1'

=== added directory 'image-builder/imagebuilder/resources'
=== added file 'image-builder/imagebuilder/resources/__init__.py'
=== added file 'image-builder/imagebuilder/resources/root.py'
--- image-builder/imagebuilder/resources/root.py	1970-01-01 00:00:00 +0000
+++ image-builder/imagebuilder/resources/root.py	2013-12-12 05:20:33 +0000
@@ -0,0 +1,30 @@
+# Ubuntu CI Services
+# Copyright 2013 Canonical Ltd.
+
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License version 3, as
+# published by the Free Software Foundation.
+
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+# PURPOSE.  See the GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+import logging
+
+from restish import resource
+
+from imagebuilder.resources import v1
+
+
+log = logging.getLogger(__name__)
+
+
+class Root(resource.Resource):
+    @resource.child('api/v1')
+    def api(self, request, segments):
+        log.debug('[api]: %s %s', request.url, str(segments))
+        return v1.API()

=== added file 'image-builder/imagebuilder/resources/v1.py'
--- image-builder/imagebuilder/resources/v1.py	1970-01-01 00:00:00 +0000
+++ image-builder/imagebuilder/resources/v1.py	2013-12-12 05:20:33 +0000
@@ -0,0 +1,40 @@
+# Ubuntu CI Services
+# Copyright 2013 Canonical Ltd.
+
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License version 3, as
+# published by the Free Software Foundation.
+
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+# PURPOSE.  See the GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+import json
+import logging
+
+from restish import http, resource
+
+log = logging.getLogger(__name__)
+
+
+class API(resource.Resource):
+
+    @resource.child('status')
+    def status(self, request, segments):
+        log.debug('[status]: %s %s', request.url, str(segments))
+        return http.ok([('Content-Type', 'application/json')], "{}")
+
+    @resource.child()
+    def build_image(self, request, segments):
+        return self._return_json(request)
+
+    def _return_json(self, request):
+        try:
+            params = json.loads(request.body)
+        except ValueError:
+            return http.bad_request()
+        return http.ok([('Content-Type', 'application/json')], str(params))

=== added directory 'image-builder/imagebuilder/tests'
=== added file 'image-builder/imagebuilder/tests/__init__.py'
=== added file 'image-builder/imagebuilder/tests/test_api_v1.py'
--- image-builder/imagebuilder/tests/test_api_v1.py	1970-01-01 00:00:00 +0000
+++ image-builder/imagebuilder/tests/test_api_v1.py	2013-12-12 05:20:33 +0000
@@ -0,0 +1,38 @@
+# Ubuntu CI Services
+# Copyright 2013 Canonical Ltd.
+
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License version 3, as
+# published by the Free Software Foundation.
+
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+# PURPOSE.  See the GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+import unittest
+
+import webtest
+
+from imagebuilder import wsgi
+
+
+class TestAPI(unittest.TestCase):
+    def setUp(self):
+        super(TestAPI, self).setUp()
+        self.app = webtest.TestApp(wsgi.app, relative_to='.')
+
+    def test_status(self):
+        resp = self.app.get('/api/v1/status')
+        self.assertEqual(200, resp.status_code)
+
+    def test_build_image(self):
+        resp = self.app.post_json('/api/v1/build_image', {})
+        self.assertEqual(200, resp.status_code)
+
+    def test_bad_build_image(self):
+        resp = self.app.post('/api/v1/build_image', 'test', status=400)
+        self.assertEqual(400, resp.status_code)

=== added file 'image-builder/imagebuilder/wsgi.py'
--- image-builder/imagebuilder/wsgi.py	1970-01-01 00:00:00 +0000
+++ image-builder/imagebuilder/wsgi.py	2013-12-12 05:20:33 +0000
@@ -0,0 +1,39 @@
+#!/usr/bin/env python
+# Ubuntu CI Services
+# Copyright 2013 Canonical Ltd.
+
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License version 3, as
+# published by the Free Software Foundation.
+
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+# PURPOSE.  See the GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+import logging
+from restish.app import RestishApp
+
+from imagebuilder.resources.root import Root
+
+logging.basicConfig(level=logging.DEBUG)
+
+
+def make_app():
+    """Build the wsgi app object."""
+    app = RestishApp(Root())
+    return app
+
+app = make_app()
+
+if __name__ == '__main__':
+    from wsgiref.simple_server import make_server
+    httpd = make_server('', 8000, app)
+    try:
+        httpd.serve_forever()
+    except KeyboardInterrupt:
+        print('exiting')
+        pass

=== added file 'image-builder/setup.py'
--- image-builder/setup.py	1970-01-01 00:00:00 +0000
+++ image-builder/setup.py	2013-12-12 05:20:33 +0000
@@ -0,0 +1,44 @@
+#!/usr/bin/env python
+# Ubuntu CI Services
+# Copyright 2013 Canonical Ltd.
+
+# This program is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Affero General Public License version 3, as
+# published by the Free Software Foundation.
+
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranties of
+# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
+# PURPOSE.  See the GNU Affero General Public License for more details.
+
+# You should have received a copy of the GNU Affero General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+import os
+
+from setuptools import find_packages, setup
+
+# ensure find_packages works if our current directory isn't this project
+basedir = os.path.abspath(os.path.dirname(__file__))
+os.chdir(basedir)
+packages = find_packages(basedir)
+
+import imagebuilder
+
+requires = [
+    'restish==0.12.1',
+    'amqplib==1.0.0',
+    'mock==1.0.1',
+    'WebTest==2.0.10',
+]
+
+setup(
+    name='image-builder',
+    version=imagebuilder.__version__,
+    description='Image Builder component of Ubuntu CI Services',
+    author='Canonical CI Engineering Team',
+    license='AGPL',
+    packages=packages,
+    test_suite='tests',
+    install_requires=requires,
+)

